import { ChainId } from "./chainid";
import { SwapPools } from "../swappools";
const ETH_TOKEN_CHAINS = [
    ChainId.ETH,
    ChainId.OPTIMISM,
    ChainId.BOBA,
    ChainId.ARBITRUM,
    ChainId.AVALANCHE,
];
export var Networks;
(function (Networks) {
    class Network {
        constructor(args) {
            this.name = args.name;
            this.names = args.names || [];
            this.chainId = args.chainId;
            this.chainCurrency = args.chainCurrency;
            this.tokens = SwapPools.getAllSwappableTokensForNetwork(this.chainId);
            this.tokenAddresses = this.tokens.map((t) => t.address(this.chainId));
        }
        get zapIsL2BridgeZap() {
            return this.chainId !== ChainId.ETH;
        }
        supportsToken(token) {
            if ((token.symbol === "ETH") && ETH_TOKEN_CHAINS.includes(this.chainId)) {
                return true;
            }
            else if (this.chainId === ChainId.ETH && token.symbol === "WETH") {
                return true;
            }
            return this.tokenAddresses.includes(token.address(this.chainId));
        }
    }
    Networks.Network = Network;
    Networks.ETH = new Network({
        name: "Ethereum Mainnet",
        chainId: ChainId.ETH,
        chainCurrency: "ETH"
    });
    Networks.OPTIMISM = new Network({
        name: "Optimism",
        chainId: ChainId.OPTIMISM,
        chainCurrency: "ETH"
    });
    Networks.BSC = new Network({
        name: "Binance Smart Chain",
        chainId: ChainId.BSC,
        chainCurrency: "BNB",
    });
    Networks.POLYGON = new Network({
        name: "Polygon",
        chainId: ChainId.POLYGON,
        chainCurrency: "MATIC",
    });
    Networks.FANTOM = new Network({
        name: "Fantom",
        chainId: ChainId.FANTOM,
        chainCurrency: "FTM",
    });
    Networks.BOBA = new Network({
        name: "Boba Network",
        chainId: ChainId.BOBA,
        chainCurrency: "ETH",
    });
    Networks.MOONRIVER = new Network({
        name: "Moonriver",
        chainId: ChainId.MOONRIVER,
        chainCurrency: "MOVR",
    });
    Networks.ARBITRUM = new Network({
        name: "Arbitrum",
        chainId: ChainId.ARBITRUM,
        chainCurrency: "ETH",
    });
    Networks.AVALANCHE = new Network({
        name: "Avalanche C-Chain",
        chainId: ChainId.AVALANCHE,
        chainCurrency: "AVAX",
    });
    Networks.AURORA = new Network({
        name: "Aurora",
        chainId: ChainId.AURORA,
        chainCurrency: "aETH",
    });
    Networks.HARMONY = new Network({
        name: "Harmony",
        chainId: ChainId.HARMONY,
        chainCurrency: "ONE",
    });
    const CHAINID_NETWORK_MAP = {
        [ChainId.ETH]: Networks.ETH,
        [ChainId.OPTIMISM]: Networks.OPTIMISM,
        [ChainId.BSC]: Networks.BSC,
        [ChainId.POLYGON]: Networks.POLYGON,
        [ChainId.FANTOM]: Networks.FANTOM,
        [ChainId.BOBA]: Networks.BOBA,
        [ChainId.MOONRIVER]: Networks.MOONRIVER,
        [ChainId.ARBITRUM]: Networks.ARBITRUM,
        [ChainId.AVALANCHE]: Networks.AVALANCHE,
        [ChainId.AURORA]: Networks.AURORA,
        [ChainId.HARMONY]: Networks.HARMONY,
    };
    Networks.fromChainId = (chainId) => { var _a; return (_a = CHAINID_NETWORK_MAP[ChainId.asNumber(chainId)]) !== null && _a !== void 0 ? _a : null; };
    function networkSupportsToken(network, token) {
        network = network instanceof Network ? network : Networks.fromChainId(network);
        return network.supportsToken(token);
    }
    Networks.networkSupportsToken = networkSupportsToken;
    Networks.supportedNetworks = () => Object.values(CHAINID_NETWORK_MAP);
})(Networks || (Networks = {}));
export const supportedNetworks = Networks.supportedNetworks;
