import { Token } from "../token";
import type { BaseToken } from "../token";
export declare namespace SwapPools {
    export class SwapToken implements BaseToken {
        readonly baseToken: Token;
        readonly poolId: number;
        readonly poolName: string;
        readonly poolType: string;
        readonly swapEthAddresses: {
            [chainid: number]: string;
        };
        readonly swapAddresses: {
            [chainid: number]: string;
        };
        readonly poolTokens: Token[];
        readonly nativeTokens: Token[];
        readonly depositTokens: Token[];
        constructor(args: {
            name: string;
            symbol: string;
            decimals: number | {
                [k: number]: number;
            };
            addresses: {
                [k: number]: string;
            };
            poolId: number;
            poolName: string;
            poolType: string;
            swapAddresses: {
                [chainid: number]: string;
            };
            swapEthAddresses?: {
                [chainid: number]: string;
            };
            poolTokens: Token[];
            nativeTokens?: Token[];
            depositTokens?: Token[];
        });
        get name(): string;
        get symbol(): string;
        get addresses(): {
            [k: number]: string;
        };
        get swapType(): string;
        get hash(): string;
        address(chainId: number): string | null;
        decimals(chainId: number): number | null;
        get poolTokensForBridgeSwaps(): Token[];
    }
    export const ETH_POOL_SWAP_TOKEN: SwapToken;
    export const OPTIMISM_ETH_SWAP_TOKEN: SwapToken;
    export const BSC_POOL_SWAP_TOKEN: SwapToken;
    export const POLYGON_POOL_SWAP_TOKEN: SwapToken;
    export const FANTOM_POOL_SWAP_TOKEN: SwapToken;
    export const BOBA_POOL_SWAP_TOKEN: SwapToken;
    export const BOBA_ETH_SWAP_TOKEN: SwapToken;
    export const ARBITRUM_POOL_SWAP_TOKEN: SwapToken;
    export const ARBITRUM_ETH_SWAP_TOKEN: SwapToken;
    export const AVALANCHE_POOL_SWAP_TOKEN: SwapToken;
    export const AVALANCHE_ETH_SWAP_TOKEN: SwapToken;
    export const AURORA_POOL_SWAP_TOKEN: SwapToken;
    export const HARMONY_POOL_SWAP_TOKEN: SwapToken;
    export const HARMONY_ONEETH_TOKEN: SwapToken;
    export interface SwapGroupTokenMap {
        [grp: string]: Token[];
    }
    export interface BridgeTokensBySwapGroupMap {
        [c: number]: SwapGroupTokenMap;
    }
    export const bridgeSwappableTokensByType: BridgeTokensBySwapGroupMap;
    interface TokenPool {
        poolTokens: Token[];
    }
    interface SwapTypeTokenPool {
        [s: string]: TokenPool;
    }
    export const bridgeSwappableTypePoolsByChain: {
        [x: number]: SwapTypeTokenPool;
    };
    export function getAllSwappableTokensForNetwork(chainId: number): Token[];
    export const swapGroupsForNetwork: (chainId: number) => string[];
    export {};
}
export interface NetworkSwappableTokensMap {
    [c: number]: Token[];
}
export interface AllNetworksSwappableTokensMap {
    [c: number]: NetworkSwappableTokensMap;
}
export declare function swappableTokens(chainIdA: number, chainIdB?: number): NetworkSwappableTokensMap;
export declare function networkSwapTokensMap(chainIdA: number, chainIdB?: number): NetworkSwappableTokensMap;
export declare function swappableTokensAllNetworks(): AllNetworksSwappableTokensMap;
export declare function allNetworksSwapTokensMap(): AllNetworksSwappableTokensMap;
